@@ -28,8 +28,9 @@ class WechetLogin(APIView):
         if not phone_code:
             return util_response(err=6558, msg='参数错误')
         app = WechatService()
-        err, data = app.wechat_login(phone_code=phone_code, login_code=login_code, sso_serve_id=sso_serve_id, detail_params=params)
-        if err == 0:
+        data, err = app.wechat_login(phone_code=phone_code, login_code=login_code, sso_serve_id=sso_serve_id,
+                                        detail_params=params)
+        if data:
             return util_response(data=data)
         else:
             logger.error('---登录错误：' + err + '---')
