@@ -6,23 +6,21 @@
 @synopsis: 小程序SDK
 @created_time: 2022/7/7 9:38
 """
-from datetime import datetime, timedelta
 import json
 from logging import getLogger
 from pathlib import Path
 
-from django.contrib.auth.hashers import make_password
-import jwt
+from django.forms import model_to_dict
 import requests
 
 from main.settings import BASE_DIR
-from ..models import BaseInfo, Auth, UserSsoToUser
+from xj_user.services.wechat_service import WechatService
+from ..models import BaseInfo
 from ..services.user_detail_info_service import DetailInfoService
 from ..services.user_relate_service import UserRelateToUserService
 from ..utils.custom_tool import get_short_id
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
-from ..utils.model_handle import parse_model
 from ..utils.nickname_generate import gen_one_word_digit
 
 module_root = str(Path(__file__).resolve().parent)
@@ -71,105 +69,84 @@ class UserSmsService:
         if detail_params is None:
             detail_params = {}
         # 根据手机号获取用户
-        current_user = BaseInfo.objects.filter(phone=phone).filter()
-        current_user = parse_model(current_user)
-        # 根据 小程序code换取openid
-        openid = ""
-        if login_code:
-            wechat_openid = self.get_openid(code=login_code)
-            openid = wechat_openid.get("openid", "")
+        current_user = BaseInfo.objects.filter(phone=phone).first()
+        # print(">>>用户信息 current_user ", current_user)
 
-        # 如果当前用户不存在则注册在登录授权
+        # 根据小程序code换取openid
+        wechat_openid = self.get_openid(code=login_code)
+
+        if wechat_openid.get("openid", None) is None:
+            return None, "获取 openid 失败,请检查code是否过期"
+
+        openid = wechat_openid.get("openid", "")
+        unionid = wechat_openid.get("unionid", "")
+
+        if not sso_serve_id:
+            return None, "平台不能为空"
+
+        # 如果用户未注册 用手机号进行注册
         if not current_user:
-            # 进行注册用户基础信息
             base_info = {
                 'user_name': get_short_id(8),
                 'nickname': gen_one_word_digit(),
                 'phone': phone,
                 'email': '',
-                'full_name': '请修改用户名',
             }
             BaseInfo.objects.create(**base_info)
-            current_user = BaseInfo.objects.filter(phone=phone).filter()
-            current_user = parse_model(current_user)
-            current_user = current_user[0]
+
+            # 注册完成后 重新获取用户信息
+            user_info_set = BaseInfo.objects.filter(phone=phone).first()
+            user_info = model_to_dict(user_info_set)
 
             # 用户第一次登录即注册，允许添加用户的详细信息
             try:
-                detail_params.setdefault("user_id", current_user.get('id', None))
+                detail_params.setdefault("user_id", user_info.get('id', None))
+                detail_params.setdefault("score", "5")  # 用户评分初始化，镖行天下业务逻辑
                 data, detail_err = DetailInfoService.create_or_update_detail(detail_params)
                 if detail_err:
                     raise Exception(detail_err)
             except Exception as e:
                 logger.error('---首次登录写入用户详细信息异常：' + str(e) + '---')
 
-            # 进行单点登录相关操作
-            if sso_serve_id:
-                sso_data = {
-                    "sso_serve_id": sso_serve_id,
-                    "user_id": current_user.get('id', None),
-                    "sso_unicode": openid,
-                    "app_id": sub_appid
-                }
-                UserSsoToUser.objects.create(**sso_data)
+            # 检验单点登录信息
+            sso_set, sso_err = WechatService.sso_verify(sso_serve_id, user_info.get('id', None), sub_appid, openid,
+                                                        unionid)
+            if sso_err:
+                return None, sso_err
+
             # 生成登录token
-            token = self.__set_token(current_user.get('id', None), phone)
+            token = WechatService.set_token(user_info.get('id', None), phone)
+
             # 创建用户登录信息，绑定token
-            auth = {
-                'user_id': current_user.get('id', None),
-                'password': make_password('123456', None, 'pbkdf2_sha1'),
-                'plaintext': '123456',
-                'token': token,
-            }
-            Auth.objects.update_or_create({'user_id': current_user.get('id', None)}, **auth)
-            auth_set = Auth.objects.filter(
-                user_id=current_user.get('id', None),
-                password__isnull=False
-            ).order_by('-update_time').first()
-            return 0, {'token': auth_set.token, 'user_info': current_user}
+            auth_set, auth_err = WechatService.get_token(user_info.get('id', None), token)
+            if auth_err:
+                return None, auth_err
+            return {'token': auth_set.token, 'user_info': user_info}, None
+        # 如果用户已经存在
         else:
             # 存在当前用户，直接进行授权
-            current_user = current_user[0]
-            sso = UserSsoToUser.objects.filter(user_id=current_user.get('id', None), app_id=sub_appid).first()
-            if not sso:
-                if sso_serve_id:
-                    sso_data = {
-                        "sso_serve_id": sso_serve_id,
-                        "user_id": current_user.get('id', None),
-                        "sso_unicode": openid,
-                        "app_id": sub_appid
-                    }
-                    UserSsoToUser.objects.create(**sso_data)
-            token = self.__set_token(current_user.get('id', None), phone)
-            # 创建用户登录信息，绑定token
-            auth = {
-                'token': token,
-            }
-            Auth.objects.filter(user_id=current_user.get('id', None)).update(**auth)
-            auth_set = Auth.objects.filter(
-                user_id=current_user.get('id', None),
-                password__isnull=False
-            ).order_by('-update_time').first()
+            user_info = model_to_dict(current_user)
+            # 检验单点登录信息
+            sso_set, sso_err = WechatService.sso_verify(sso_serve_id, user_info.get('id', None), sub_appid, openid,
+                                                        unionid)
+            if sso_err:
+                return None, sso_err
 
-        # 绑定用户关系 邀请关系和收益关系
-        data, relate_err = UserRelateToUserService.bind_bxtx_relate(params=detail_params, user_info=current_user)
+            # 创建用户登录信息，绑定token
+            token = WechatService.set_token(user_info.get('id', None), user_info.get('phone', None))
+            # 修改用户登录信息，绑定token
+            auth_set, auth_err = WechatService.get_token(user_id=user_info.get('id', None), token=token,
+                                                         is_create=False)
+            if auth_err:
+                return None, auth_err
+
+            # 绑定用户关系 邀请关系和收益关系
+        data, relate_err = UserRelateToUserService.bind_bxtx_relate(params=detail_params, user_info=user_info)
         if relate_err:
             logger.error(
                 '绑定用户关系异常：' + str(relate_err) +
-                ' \n当前用户ID:' + str(current_user.get("id", "")) +
+                ' \n当前用户ID:' + str(user_info.get("id", "")) +
                 '\n detail_params:' + json.dumps(detail_params)
             )
 
-        return 0, {'token': auth_set.token, 'user_info': current_user}
-
-    def __set_token(self, user_id, account):
-        # 生成过期时间
-        expire_timestamp = datetime.utcnow() + timedelta(
-            days=7,
-            seconds=0
-        )
-        # 返回token
-        return jwt.encode(
-            payload={'user_id': user_id, 'account': account, "exp": expire_timestamp},
-            key=jwt_secret_key
-        )
+        return {'token': auth_set.token, 'user_info': user_info}, None
